var searchData=
[
  ['tagss_5ftime2_5fstruct_0',['tagSS_TIME2_STRUCT',['../a01389.html',1,'']]],
  ['tagss_5ftimestampoffset_5fstruct_1',['tagSS_TIMESTAMPOFFSET_STRUCT',['../a01393.html',1,'']]],
  ['tds_2',['tds',['../a01101.html#ad357e33164f46fce2bc70267d71a1959',1,'_hstmt::tds'],['../a01333.html#a182ed346382edef2962aca11c7cabc22',1,'tds_freeze::tds']]],
  ['tds_2eh_3',['tds.h',['../a00431.html',1,'']]],
  ['tds4_5fsend_5femulated_5frpc_4',['tds4_send_emulated_rpc',['../a00593.html#ga2d0a06c1a30dd2470dc7a788de21b080',1,'query.c']]],
  ['tds5_5fbcp_5fadd_5ffixed_5fcolumns_5',['tds5_bcp_add_fixed_columns',['../a00254.html#a91cf6a009e823417d6c8849256cb211c',1,'bulk.c']]],
  ['tds5_5fbcp_5fadd_5fvariable_5fcolumns_6',['tds5_bcp_add_variable_columns',['../a00254.html#a5c906a8b65694148ad530a22ce019f06',1,'bulk.c']]],
  ['tds5_5fcolinfo_7',['tds5_colinfo',['../a01337.html',1,'']]],
  ['tds5_5ffix_5fdot_5fquery_8',['tds5_fix_dot_query',['../a00593.html#ga8853354723094c8efcd87fabf675c64f',1,'query.c']]],
  ['tds5_5fprocess_5fdyn_5fresult2_9',['tds5_process_dyn_result2',['../a00595.html#gae688b515631141acfbc41bbb91c8b921',1,'token.c']]],
  ['tds5_5fprocess_5foptioncmd_10',['tds5_process_optioncmd',['../a00595.html#gaa6a7e5aeb10a1322911c47be9c43e2d2',1,'token.c']]],
  ['tds5_5fprocess_5fresult_11',['tds5_process_result',['../a00595.html#ga547b2f48659f77a69aa802d861ac827d',1,'token.c']]],
  ['tds5_5fprocess_5fresult2_12',['tds5_process_result2',['../a00595.html#gabe2bdd5a41ce067cb31aef18ff81cb1c',1,'token.c']]],
  ['tds5_5fput_5fparams_13',['tds5_put_params',['../a00593.html#ga4f1f0a4f77bc4ea1440dfdebc19a157c',1,'query.c']]],
  ['tds71_5fcollation_14',['TDS71_COLLATION',['../a01149.html',1,'']]],
  ['tds71_5fread_5ftable_5fnames_15',['tds71_read_table_names',['../a00595.html#ga7482b5730d880fcedbe9fcd609a550ce',1,'token.c']]],
  ['tds71_5fsubmit_5fprepexec_16',['tds71_submit_prepexec',['../a00593.html#ga08877c101704bebe4fa57e0849dc272d',1,'tds71_submit_prepexec(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c'],['../a00593.html#ga08877c101704bebe4fa57e0849dc272d',1,'tds71_submit_prepexec(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c']]],
  ['tds72_5fsmp_5fheader_17',['TDS72_SMP_HEADER',['../a01157.html',1,'']]],
  ['tds7_5fbcp_5fsend_5fcolmetadata_18',['tds7_bcp_send_colmetadata',['../a00254.html#a4daaa551e54dbd978650e2eef89e09ff',1,'bulk.c']]],
  ['tds7_5fbuild_5fbulk_5finsert_5fstmt_19',['tds7_build_bulk_insert_stmt',['../a00254.html#a3118c7232bc9c3e47f8ba872bb39e967',1,'bulk.c']]],
  ['tds7_5fget_5fdata_5finfo_20',['tds7_get_data_info',['../a00595.html#ga07cee55fd522cca16fb59b7a8f0b1376',1,'token.c']]],
  ['tds7_5fget_5finstance_5fport_21',['tds7_get_instance_port',['../a00594.html#gac23c12ccb3e8599f10f305e993e216f6',1,'tds7_get_instance_port(struct addrinfo *addr, const char *instance):&#160;net.c'],['../a00594.html#gac23c12ccb3e8599f10f305e993e216f6',1,'tds7_get_instance_port(struct addrinfo *addr, const char *instance):&#160;net.c']]],
  ['tds7_5fget_5finstance_5fports_22',['tds7_get_instance_ports',['../a00594.html#ga954dcc3b0332fa9448d9edf59c0fe439',1,'tds7_get_instance_ports(FILE *output, struct addrinfo *addr):&#160;net.c'],['../a00594.html#ga954dcc3b0332fa9448d9edf59c0fe439',1,'tds7_get_instance_ports(FILE *output, struct addrinfo *addr):&#160;net.c']]],
  ['tds7_5fprocess_5fcompute_5fresult_23',['tds7_process_compute_result',['../a00595.html#ga6728e344caa20aea1def85f58dea138b',1,'token.c']]],
  ['tds7_5fprocess_5fresult_24',['tds7_process_result',['../a00595.html#gaca56fc22d65a24a96d1bef310ade73aa',1,'token.c']]],
  ['tds7_5fput_5fquery_5fparams_25',['tds7_put_query_params',['../a00593.html#ga6e42b4a1d1d3898229ea2fe4afc2ecec',1,'query.c']]],
  ['tds7_5fsend_5fexecute_26',['tds7_send_execute',['../a00593.html#ga9f6f25dd405f45e75420e6e084bf2d85',1,'query.c']]],
  ['tds7_5fwrite_5fparam_5fdef_5ffrom_5fparams_27',['tds7_write_param_def_from_params',['../a00593.html#ga6513afd79629f7a928e1d3da9f56dee1',1,'query.c']]],
  ['tds7_5fwrite_5fparam_5fdef_5ffrom_5fquery_28',['tds7_write_param_def_from_query',['../a00593.html#ga24345856c16b15aa3e84459c2f551320',1,'query.c']]],
  ['tds8_5fadjust_5flogin_29',['tds8_adjust_login',['../a00589.html#ga9622e7d6c98a77b1962647c5005d3731',1,'tds8_adjust_login(TDSLOGIN *login):&#160;config.c'],['../a00589.html#ga9622e7d6c98a77b1962647c5005d3731',1,'tds8_adjust_login(TDSLOGIN *login):&#160;config.c']]],
  ['tds_5faddrinfo_30',['tds_addrinfo',['../a01161.html',1,'']]],
  ['tds_5falign_5fstruct_31',['tds_align_struct',['../a01213.html',1,'']]],
  ['tds_5falloc_5fcompute_5fresult_32',['tds_alloc_compute_result',['../a00592.html#ga93dcf17e404712a2c450a1b26cd5a0b7',1,'mem.c']]],
  ['tds_5falloc_5fdynamic_33',['tds_alloc_dynamic',['../a00592.html#ga69559de43b47f4a9e2eecc7a56527444',1,'tds_alloc_dynamic(TDSCONNECTION *conn, const char *id):&#160;mem.c'],['../a00592.html#ga69559de43b47f4a9e2eecc7a56527444',1,'tds_alloc_dynamic(TDSCONNECTION *conn, const char *id):&#160;mem.c']]],
  ['tds_5falloc_5fget_5fstring_34',['tds_alloc_get_string',['../a00595.html#gafb26aba5d935e40b87b95e21a5185848',1,'token.c']]],
  ['tds_5falloc_5fparam_5fdata_35',['tds_alloc_param_data',['../a00592.html#ga4bbf9a6b6d514fc62ae67f548d54d78a',1,'tds_alloc_param_data(TDSCOLUMN *curparam):&#160;mem.c'],['../a00592.html#ga4bbf9a6b6d514fc62ae67f548d54d78a',1,'tds_alloc_param_data(TDSCOLUMN *curparam):&#160;mem.c']]],
  ['tds_5falloc_5fparam_5fresult_36',['tds_alloc_param_result',['../a00592.html#ga314c65c067570dc1ef3e58bbfc4eb763',1,'tds_alloc_param_result(TDSPARAMINFO *old_param):&#160;mem.c'],['../a00592.html#ga314c65c067570dc1ef3e58bbfc4eb763',1,'tds_alloc_param_result(TDSPARAMINFO *old_param):&#160;mem.c']]],
  ['tds_5falloc_5frow_37',['tds_alloc_row',['../a00592.html#ga1224fb9277112dc2ce12531d2b73b145',1,'tds_alloc_row(TDSRESULTINFO *res_info):&#160;mem.c'],['../a00592.html#ga1224fb9277112dc2ce12531d2b73b145',1,'tds_alloc_row(TDSRESULTINFO *res_info):&#160;mem.c']]],
  ['tds_5fanswer_38',['tds_answer',['../a00761.html',1,'']]],
  ['tds_5fanswer_5fchallenge_39',['tds_answer_challenge',['../a00588.html#ga8adf4e719762fef6fdb091d15d4d5d7f',1,'challenge.c']]],
  ['tds_5fascii_5fto_5fucs2_40',['tds_ascii_to_ucs2',['../a00593.html#gad05fc65e1d505c68d14c82b99a00e4eb',1,'query.c']]],
  ['tds_5fauthentication_41',['tds_authentication',['../a01301.html',1,'']]],
  ['tds_5fbcp_5fdirections_42',['tds_bcp_directions',['../a00431.html#ad5c5c8cb776334af4b0ebf7a0d740cb2',1,'tds.h']]],
  ['tds_5fbcp_5fdone_43',['tds_bcp_done',['../a00431.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c'],['../a00254.html#ade7df2db455b61edc83819ad60edb339',1,'tds_bcp_done(TDSSOCKET *tds, int *rows_copied):&#160;bulk.c']]],
  ['tds_5fbcp_5ffread_44',['tds_bcp_fread',['../a00254.html#a86ac92bd8a3c61a413d27150ec9bc202',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *char_conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c'],['../a00431.html#a8184311543c685f2ee0bcccfb725ca02',1,'tds_bcp_fread(TDSSOCKET *tds, TDSICONV *conv, FILE *stream, const char *terminator, size_t term_len, char **outbuf, size_t *outbytes):&#160;bulk.c']]],
  ['tds_5fbcp_5finit_45',['tds_bcp_init',['../a00254.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00431.html#ac6610c72bd31bad5378f760fa9b12d66',1,'tds_bcp_init(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5frow_5ffree_46',['tds_bcp_row_free',['../a00254.html#a55bd2715b2897e9592cbbd9c6e3c86f6',1,'bulk.c']]],
  ['tds_5fbcp_5fsend_5frecord_47',['tds_bcp_send_record',['../a00431.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c'],['../a00254.html#ad9e44450025cbcee1ad81d7e5a2cc099',1,'tds_bcp_send_record(TDSSOCKET *tds, TDSBCPINFO *bcpinfo, tds_bcp_get_col_data get_col_data, tds_bcp_null_error null_error, int offset):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_48',['tds_bcp_start',['../a00431.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00254.html#a8208eef2a3974ae1f0cf3c8c8ab011ce',1,'tds_bcp_start(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_5fcopy_5fin_49',['tds_bcp_start_copy_in',['../a00254.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c'],['../a00431.html#a5eec23828b0610c58de248c4edb53879',1,'tds_bcp_start_copy_in(TDSSOCKET *tds, TDSBCPINFO *bcpinfo):&#160;bulk.c']]],
  ['tds_5fbcp_5fstart_5finsert_5fstmt_50',['tds_bcp_start_insert_stmt',['../a00254.html#ab4d7e5309152f54613d52c8469a07fd8',1,'bulk.c']]],
  ['tds_5fbcpcoldata_51',['tds_bcpcoldata',['../a01249.html',1,'']]],
  ['tds_5fbcpinfo_52',['tds_bcpinfo',['../a01341.html',1,'']]],
  ['tds_5fblob_53',['tds_blob',['../a01237.html',1,'']]],
  ['tds_5fcanonical_5fcharset_54',['tds_canonical_charset',['../a00591.html#gac01180352db7052e786463e3b07a8a9e',1,'tds_canonical_charset(const char *charset_name):&#160;iconv.c'],['../a00591.html#gac01180352db7052e786463e3b07a8a9e',1,'tds_canonical_charset(const char *charset_name):&#160;iconv.c']]],
  ['tds_5fcanonical_5fcharset_5fname_55',['tds_canonical_charset_name',['../a00591.html#ga22c61ca41f64c7fe368659ed1eebdb56',1,'tds_canonical_charset_name(const char *charset_name):&#160;iconv.c'],['../a00591.html#ga22c61ca41f64c7fe368659ed1eebdb56',1,'tds_canonical_charset_name(const char *charset_name):&#160;iconv.c']]],
  ['tds_5fcanonical_5fcollate_5fname_56',['tds_canonical_collate_name',['../a00591.html#ga4bdd3a3ef6b604c30fe013a65f598073',1,'tds_canonical_collate_name(int canonic_charset):&#160;iconv.c'],['../a00591.html#ga4bdd3a3ef6b604c30fe013a65f598073',1,'tds_canonical_collate_name(int canonical_charset):&#160;iconv.c']]],
  ['tds_5fcapabilities_57',['tds_capabilities',['../a01221.html',1,'']]],
  ['tds_5fcapability_5ftype_58',['tds_capability_type',['../a01217.html',1,'']]],
  ['tds_5fclose_5fsocket_59',['tds_close_socket',['../a00594.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c'],['../a00594.html#ga3e3f76009fce5ceedb2f42bb2c9aed2e',1,'tds_close_socket(TDSSOCKET *tds):&#160;net.c']]],
  ['tds_5fcolumn_60',['tds_column',['../a01257.html',1,'']]],
  ['tds_5fcolumn_5ffuncs_61',['tds_column_funcs',['../a01253.html',1,'']]],
  ['tds_5fcompiletime_5fsettings_62',['tds_compiletime_settings',['../a01197.html',1,'tds_compiletime_settings'],['../a00431.html#a1de034b895312fc0cfae0e28f8921a47',1,'TDS_COMPILETIME_SETTINGS:&#160;tds.h']]],
  ['tds_5fcondition_63',['tds_condition',['../a01349.html',1,'']]],
  ['tds_5fconfig_5fverstr_64',['tds_config_verstr',['../a00589.html#ga05c73c963f4d8904869c739c556c58a2',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c'],['../a00589.html#ga05c73c963f4d8904869c739c556c58a2',1,'tds_config_verstr(const char *tdsver, TDSLOGIN *login):&#160;config.c']]],
  ['tds_5fconnection_65',['tds_connection',['../a01313.html',1,'']]],
  ['tds_5fcontext_66',['tds_context',['../a01297.html',1,'']]],
  ['tds_5fconvert_67',['tds_convert',['../a00590.html#gad83c146aa5ba3f1515557d6b5248494a',1,'tds_convert(const TDSCONTEXT *tds_ctx, int srctype, const void *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c'],['../a00590.html#gad83c146aa5ba3f1515557d6b5248494a',1,'tds_convert(const TDSCONTEXT *context, int srctype, const void *src, TDS_UINT srclen, int desttype, CONV_RESULT *cr):&#160;convert.c']]],
  ['tds_5fconvert_5fstream_68',['tds_convert_stream',['../a01490.html#a9d8eb43a81ff58ab423dce0ce95b9564',1,'stream.c']]],
  ['tds_5fconvert_5fstring_69',['tds_convert_string',['../a00593.html#ga451c03a088d468a32c1cff9848dd2a6a',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, ptrdiff_t len, size_t *out_len):&#160;query.c'],['../a00593.html#ga451c03a088d468a32c1cff9848dd2a6a',1,'tds_convert_string(TDSSOCKET *tds, TDSICONV *char_conv, const char *s, ptrdiff_t len, size_t *out_len):&#160;query.c']]],
  ['tds_5fcopy_5fstream_70',['tds_copy_stream',['../a01490.html#a50bc3749988d1c3c441044fc07ab44e4',1,'stream.c']]],
  ['tds_5fcount_5fplaceholders_71',['tds_count_placeholders',['../a00593.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c'],['../a00593.html#gaaa7b4d37bf796019e72f25c6e7fe7bea',1,'tds_count_placeholders(const char *query):&#160;query.c']]],
  ['tds_5fcount_5fplaceholders_5fucs2le_72',['tds_count_placeholders_ucs2le',['../a00593.html#ga0cd19215e9169ea299a6c9cbf5b2fb60',1,'query.c']]],
  ['tds_5fctx_73',['tds_ctx',['../a00657.html#afb3fb2d591c0f75b9412f8ca77e2629d',1,'dblib_context']]],
  ['tds_5fctx_5fref_5fcount_74',['tds_ctx_ref_count',['../a00657.html#ad01d901acbc92e8c369e6a6c784d7446',1,'dblib_context']]],
  ['tds_5fcursor_75',['tds_cursor',['../a01281.html',1,'']]],
  ['tds_5fcursor_5fcheck_5fallocated_76',['tds_cursor_check_allocated',['../a00593.html#ga2a64baaf4aa50ef601a49b801dfdaaf6',1,'query.c']]],
  ['tds_5fcursor_5fdealloc_77',['tds_cursor_dealloc',['../a00593.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c'],['../a00593.html#gab25de0567ac096e8f8e88490eeddf562',1,'tds_cursor_dealloc(TDSSOCKET *tds, TDSCURSOR *cursor):&#160;query.c']]],
  ['tds_5fcursor_5fstatus_78',['tds_cursor_status',['../a01277.html',1,'']]],
  ['tds_5fdatain_5fstream_79',['tds_datain_stream',['../a01177.html',1,'']]],
  ['tds_5fdatain_5fstream_5finit_80',['tds_datain_stream_init',['../a01490.html#abc3a77c8aa28842e7f28583cbabc1415',1,'stream.c']]],
  ['tds_5fdatain_5fstream_5fread_81',['tds_datain_stream_read',['../a01490.html#a04b537d889f7d4c9b9701eb81baf7efd',1,'stream.c']]],
  ['tds_5fdataout_5fstream_82',['tds_dataout_stream',['../a01181.html',1,'']]],
  ['tds_5fdataout_5fstream_5finit_83',['tds_dataout_stream_init',['../a01490.html#aa038a9125979f8f0915dbd53cbf27e5a',1,'stream.c']]],
  ['tds_5fdataout_5fstream_5fwrite_84',['tds_dataout_stream_write',['../a01490.html#ae38a590ee08cf398e7adef536ac94538',1,'stream.c']]],
  ['tds_5fdatecrack_85',['tds_datecrack',['../a00590.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c'],['../a00590.html#ga883855e6e3793de6684b21db39c756c4',1,'tds_datecrack(TDS_INT datetype, const void *di, TDSDATEREC *dr):&#160;convert.c']]],
  ['tds_5fdatetimeall_86',['TDS_DATETIMEALL',['../a01201.html',1,'']]],
  ['tds_5fdblib_5fdbprocess_87',['tds_dblib_dbprocess',['../a01013.html',1,'']]],
  ['tds_5fdblib_5floginrec_88',['tds_dblib_loginrec',['../a00981.html',1,'']]],
  ['tds_5fdead_89',['TDS_DEAD',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33af087b64970a1fb35bbcf1bc6ea7a643d',1,'tds.h']]],
  ['tds_5fdeferred_5fcursor_5fdealloc_90',['tds_deferred_cursor_dealloc',['../a00593.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c'],['../a00593.html#ga57bd0fabe5bcdeb3ef091259b3a7c1fc',1,'tds_deferred_cursor_dealloc(TDSCONNECTION *conn, TDSCURSOR *cursor):&#160;query.c']]],
  ['tds_5fdeferred_5funprepare_91',['tds_deferred_unprepare',['../a00593.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga9f80fdf732b084aef7de7a323261aa61',1,'tds_deferred_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fdetach_5fresults_92',['tds_detach_results',['../a00592.html#ga1d60bf443e274797b1d1a9e7418ab962',1,'tds_detach_results(TDSRESULTINFO *info):&#160;mem.c'],['../a00592.html#ga1d60bf443e274797b1d1a9e7418ab962',1,'tds_detach_results(TDSRESULTINFO *info):&#160;mem.c']]],
  ['tds_5fdstr_93',['tds_dstr',['../a01381.html',1,'']]],
  ['tds_5fdstr_5falloc_94',['tds_dstr_alloc',['../a00596.html#ga6aa14b8b717b51afcfb65bd55143689d',1,'tdsstring.c']]],
  ['tds_5fdstr_5fbuf_95',['tds_dstr_buf',['../a00596.html#gae092e53680d954bcf4f19334987d43c7',1,'string.h']]],
  ['tds_5fdstr_5fcopy_96',['tds_dstr_copy',['../a00596.html#gad96366d9fa93bfc283cef1299fbe97ab',1,'tdsstring.c']]],
  ['tds_5fdstr_5fcopyn_97',['tds_dstr_copyn',['../a00596.html#ga656718f240d7403f986ae887d84a6ca1',1,'tdsstring.c']]],
  ['tds_5fdstr_5fcstr_98',['tds_dstr_cstr',['../a00596.html#gac536f0e4d77d3cff5702719362ec1766',1,'string.h']]],
  ['tds_5fdstr_5fdup_99',['tds_dstr_dup',['../a00596.html#ga4e6d9fa6f9b9551a5a3390e10a5322e6',1,'tdsstring.c']]],
  ['tds_5fdstr_5fempty_100',['tds_dstr_empty',['../a00596.html#ga42d67780bd4fd442915780d4815fc743',1,'string.h']]],
  ['tds_5fdstr_5ffree_101',['tds_dstr_free',['../a00596.html#gaccd1c1c8ff938813578123963212388c',1,'tdsstring.c']]],
  ['tds_5fdstr_5fget_102',['tds_dstr_get',['../a00594.html#ga017c427e9599c031be5c555cb32abe2c',1,'tds_dstr_get(TDSSOCKET *tds, DSTR *s, size_t len):&#160;read.c'],['../a00594.html#ga017c427e9599c031be5c555cb32abe2c',1,'tds_dstr_get(TDSSOCKET *tds, DSTR *s, size_t len):&#160;read.c']]],
  ['tds_5fdstr_5finit_103',['tds_dstr_init',['../a00596.html#ga6c0aba5c6da921898768e7f6cf177ca7',1,'string.h']]],
  ['tds_5fdstr_5fisempty_104',['tds_dstr_isempty',['../a00596.html#gae38ac42415273bf467d71aef0a9729d4',1,'string.h']]],
  ['tds_5fdstr_5flen_105',['tds_dstr_len',['../a00596.html#ga396f139e4f886ac1b224a735138e73dd',1,'string.h']]],
  ['tds_5fdstr_5fset_106',['tds_dstr_set',['../a00596.html#gab78cc59b110df2817b00f9bed74c6ff1',1,'tdsstring.c']]],
  ['tds_5fdstr_5fsetlen_107',['tds_dstr_setlen',['../a00596.html#ga0cd7863ba7c2d2da4a193234472a3d14',1,'tdsstring.c']]],
  ['tds_5fdstr_5fzero_108',['tds_dstr_zero',['../a00596.html#ga339ba30216e2bd5bd076aa9dcd26f3c4',1,'tdsstring.c']]],
  ['tds_5fdynamic_109',['tds_dynamic',['../a01289.html',1,'']]],
  ['tds_5fdynamic_5fstream_110',['tds_dynamic_stream',['../a01193.html',1,'']]],
  ['tds_5fdynamic_5fstream_5finit_111',['tds_dynamic_stream_init',['../a01490.html#a4f9e40da6941cb9407d0da5bc3030517',1,'stream.c']]],
  ['tds_5fdynamic_5fstream_5fwrite_112',['tds_dynamic_stream_write',['../a01490.html#abaf688c85ea04a2392103d519a55d04e',1,'stream.c']]],
  ['tds_5fencoding_113',['tds_encoding',['../a01245.html',1,'tds_encoding'],['../a00431.html#ae21e9f12e8ee5219228ee6b6a41dec66',1,'TDS_ENCODING:&#160;tds.h']]],
  ['tds_5fenv_114',['tds_env',['../a01285.html',1,'']]],
  ['tds_5ferrno_5fmessage_5fflags_115',['tds_errno_message_flags',['../a01045.html',1,'']]],
  ['tds_5ferror_5fmessage_116',['tds_error_message',['../a00829.html',1,'']]],
  ['tds_5ffile_5fstream_117',['tds_file_stream',['../a00757.html',1,'']]],
  ['tds_5ffile_5fstream_5fread_118',['tds_file_stream_read',['../a00254.html#a1b83c9db016b481aa1fa0352f976d50d',1,'bulk.c']]],
  ['tds_5ffix_5fcolumn_5fsize_119',['tds_fix_column_size',['../a00593.html#ga79e31bdb1d8e8e214ea2bed964ff0e77',1,'query.c']]],
  ['tds_5ffix_5flogin_120',['tds_fix_login',['../a00589.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c'],['../a00589.html#gacee4f06ba749b10ee9f2e5bb1c4a8910',1,'tds_fix_login(TDSLOGIN *login):&#160;config.c']]],
  ['tds_5fflush_5fpacket_121',['tds_flush_packet',['../a00594.html#ga5feb53554e8917a81bbbc332163a61fb',1,'tds_flush_packet(TDSSOCKET *tds):&#160;write.c'],['../a00594.html#ga5feb53554e8917a81bbbc332163a61fb',1,'tds_flush_packet(TDSSOCKET *tds):&#160;write.c']]],
  ['tds_5ffree_5finput_5fparams_122',['tds_free_input_params',['../a00592.html#gabdc5fee73b22345c02ab894e49ad7f95',1,'tds_free_input_params(TDSDYNAMIC *dyn):&#160;mem.c'],['../a00592.html#gabdc5fee73b22345c02ab894e49ad7f95',1,'tds_free_input_params(TDSDYNAMIC *dyn):&#160;mem.c']]],
  ['tds_5ffree_5fnamelist_123',['tds_free_namelist',['../a00595.html#ga21e9de33de9c8c492aa2f96c823596bb',1,'token.c']]],
  ['tds_5ffree_5fparam_5fresult_124',['tds_free_param_result',['../a00592.html#ga66cd6e3c5089ced9415a8a0e258d205a',1,'tds_free_param_result(TDSPARAMINFO *param_info):&#160;mem.c'],['../a00592.html#ga66cd6e3c5089ced9415a8a0e258d205a',1,'tds_free_param_result(TDSPARAMINFO *param_info):&#160;mem.c']]],
  ['tds_5ffreeze_125',['tds_freeze',['../a00594.html#ga6b2b012b999bd0a4f159fabc8d11a5bf',1,'tds_freeze(TDSSOCKET *tds, TDSFREEZE *freeze, unsigned size_len):&#160;packet.c'],['../a00594.html#ga6b2b012b999bd0a4f159fabc8d11a5bf',1,'tds_freeze(TDSSOCKET *tds, TDSFREEZE *freeze, unsigned size_len):&#160;packet.c'],['../a01333.html',1,'tds_freeze']]],
  ['tds_5ffreeze_5fabort_126',['tds_freeze_abort',['../a00594.html#ga7274d9c5dc75c58bb7d1f1c29e03a73e',1,'tds_freeze_abort(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga7274d9c5dc75c58bb7d1f1c29e03a73e',1,'tds_freeze_abort(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffreeze_5fclose_127',['tds_freeze_close',['../a00594.html#ga633f62fb8e5310abfa42c02fba9c6500',1,'tds_freeze_close(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga633f62fb8e5310abfa42c02fba9c6500',1,'tds_freeze_close(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffreeze_5fclose_5flen_128',['tds_freeze_close_len',['../a00594.html#ga2660b893ae2bf36fe1b63b354e748bad',1,'tds_freeze_close_len(TDSFREEZE *freeze, int32_t size):&#160;packet.c'],['../a00594.html#ga2660b893ae2bf36fe1b63b354e748bad',1,'tds_freeze_close_len(TDSFREEZE *freeze, int32_t size):&#160;packet.c']]],
  ['tds_5ffreeze_5fclose_5fstring_129',['tds_freeze_close_string',['../a00594.html#ga084fa9cda46be8594997fed2487fcb50',1,'tds_freeze_close_string(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga084fa9cda46be8594997fed2487fcb50',1,'tds_freeze_close_string(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffreeze_5fwritten_130',['tds_freeze_written',['../a00594.html#ga1daa50429a3a5b045ee503581e859a8b',1,'tds_freeze_written(TDSFREEZE *freeze):&#160;packet.c'],['../a00594.html#ga1daa50429a3a5b045ee503581e859a8b',1,'tds_freeze_written(TDSFREEZE *freeze):&#160;packet.c']]],
  ['tds_5ffuncs_131',['TDS_FUNCS',['../a01105.html',1,'']]],
  ['tds_5fgeneric_5fget_132',['tds_generic_get',['../a00263.html#abac4d689e0e31e80587f89247c6395a4',1,'data.c']]],
  ['tds_5fgeneric_5fput_133',['tds_generic_put',['../a00263.html#a84e17808683ba2dd956e811a42e23176',1,'data.c']]],
  ['tds_5fgeneric_5fput_5finfo_134',['tds_generic_put_info',['../a00263.html#aabd0e5f15615b5c141c525b76e746520',1,'data.c']]],
  ['tds_5fget_5fbyte_135',['tds_get_byte',['../a00594.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga0cb72d3f6943795c39db1fa692be0a58',1,'tds_get_byte(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fchar_5fdata_136',['tds_get_char_data',['../a00594.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *row_buffer, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c'],['../a00594.html#ga8d214089b6e97fc0da5e0be09f216d73',1,'tds_get_char_data(TDSSOCKET *tds, char *dest, size_t wire_size, TDSCOLUMN *curcol):&#160;read.c']]],
  ['tds_5fget_5fcolumn_5fdeclaration_137',['tds_get_column_declaration',['../a00593.html#ga50d62edeb2a432e2dc668263f3f958ff',1,'tds_get_column_declaration(TDSSOCKET *tds, TDSCOLUMN *curcol, char *out):&#160;query.c'],['../a00593.html#ga50d62edeb2a432e2dc668263f3f958ff',1,'tds_get_column_declaration(TDSSOCKET *tds, TDSCOLUMN *curcol, char *out):&#160;query.c']]],
  ['tds_5fget_5fcompiletime_5fsettings_138',['tds_get_compiletime_settings',['../a00589.html#ga0c00a50e074cec7fbb0a1de826a4a46b',1,'tds_get_compiletime_settings(void):&#160;config.c'],['../a00589.html#ga0c00a50e074cec7fbb0a1de826a4a46b',1,'tds_get_compiletime_settings(void):&#160;config.c']]],
  ['tds_5fget_5fconversion_5ftype_139',['tds_get_conversion_type',['../a00431.html#a0383d5dcb629582266a442f0f0dbd13a',1,'tds_types.h']]],
  ['tds_5fget_5fdata_5finfo_140',['tds_get_data_info',['../a00595.html#gad9b6b86f48be077fb44ac603845a0c27',1,'token.c']]],
  ['tds_5fget_5fdynid_141',['tds_get_dynid',['../a00592.html#ga93503e64091b51add0801abebe22abf4',1,'mem.c']]],
  ['tds_5fget_5flocale_142',['tds_get_locale',['../a00431.html#a41390fa6e1083ba84fb523797e6b5275',1,'locale.c']]],
  ['tds_5fget_5fn_143',['tds_get_n',['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t need):&#160;read.c'],['../a00594.html#gae777dd57e8d1bb40349d7d7d8434fddf',1,'tds_get_n(TDSSOCKET *tds, void *dest, size_t n):&#160;read.c']]],
  ['tds_5fget_5fnull_5ftype_144',['tds_get_null_type',['../a00590.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c'],['../a00590.html#ga68e3a76fd7b0a77614765826a8ab5be8',1,'tds_get_null_type(TDS_SERVER_TYPE srctype):&#160;convert.c']]],
  ['tds_5fget_5fsize_5fby_5ftype_145',['tds_get_size_by_type',['../a00431.html#a4c070147d189dede5e08a2dc66852678',1,'tds_types.h']]],
  ['tds_5fget_5fsocket_5ferror_146',['tds_get_socket_error',['../a00594.html#ga4a2418e0a4533d616ef3da526236f2b8',1,'net.c']]],
  ['tds_5fget_5fstring_147',['tds_get_string',['../a00594.html#ga90f080e6e9448feac15dee1370d66802',1,'tds_get_string(TDSSOCKET *tds, size_t string_len, char *dest, size_t dest_size):&#160;read.c'],['../a00594.html#ga90f080e6e9448feac15dee1370d66802',1,'tds_get_string(TDSSOCKET *tds, size_t string_len, char *dest, size_t dest_size):&#160;read.c']]],
  ['tds_5fget_5fuint_148',['tds_get_uint',['../a00594.html#ga9ac121c269e203337a48c5bf8afc48c3',1,'tds_get_uint(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga9ac121c269e203337a48c5bf8afc48c3',1,'tds_get_uint(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fuint8_149',['tds_get_uint8',['../a00594.html#ga8ab6c87318eaf15ea17a9575763f7809',1,'tds_get_uint8(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga8ab6c87318eaf15ea17a9575763f7809',1,'tds_get_uint8(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fusmallint_150',['tds_get_usmallint',['../a00594.html#gad38aa5b9547817854ccba1fcc7855861',1,'tds_get_usmallint(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#gad38aa5b9547817854ccba1fcc7855861',1,'tds_get_usmallint(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fget_5fvarint_5fsize_151',['tds_get_varint_size',['../a00431.html#a68855f1251759a6b7338635306ab0041',1,'tds_types.h']]],
  ['tds_5fgoodread_152',['tds_goodread',['../a00594.html#gaa1466c5305333503d6fae82dc271256a',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, size_t buflen):&#160;net.c'],['../a00594.html#gaa1466c5305333503d6fae82dc271256a',1,'tds_goodread(TDSSOCKET *tds, unsigned char *buf, size_t buflen):&#160;net.c']]],
  ['tds_5fgoodwrite_153',['tds_goodwrite',['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c'],['../a00594.html#gae19543ec756e7ef8327d643899db9fb8',1,'tds_goodwrite(TDSSOCKET *tds, const unsigned char *buffer, size_t buflen):&#160;net.c']]],
  ['tds_5fheader_154',['TDS_HEADER',['../a01153.html',1,'']]],
  ['tds_5fheaders_155',['tds_headers',['../a01229.html',1,'']]],
  ['tds_5ficonv_156',['tds_iconv',['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *char_conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c'],['../a00591.html#ga87db49044919f1bc84c0ff5e9ab00304',1,'tds_iconv(TDSSOCKET *tds, TDSICONV *conv, TDS_ICONV_DIRECTION io, const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft):&#160;iconv.c']]],
  ['tds_5ficonv_5falloc_157',['tds_iconv_alloc',['../a01502.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c'],['../a00431.html#a026957dbbd994b48b571a63405f427cd',1,'tds_iconv_alloc(TDSCONNECTION *conn):&#160;iconv.c']]],
  ['tds_5ficonv_5ffrom_5fcollate_158',['tds_iconv_from_collate',['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c'],['../a00591.html#gac4d0a96ba5e8c72bb5961c63453cc940',1,'tds_iconv_from_collate(TDSCONNECTION *conn, const TDS_UCHAR collate[5]):&#160;iconv.c']]],
  ['tds_5ficonv_5fget_5finfo_159',['tds_iconv_get_info',['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c'],['../a00591.html#ga1639ccaa7e17c07457bcb37f313bc52f',1,'tds_iconv_get_info(TDSCONNECTION *conn, int canonic_client, int canonic_server):&#160;iconv.c']]],
  ['tds_5ficonv_5finfo_5finit_160',['tds_iconv_info_init',['../a00591.html#ga372010075a93be5ea4de15ab63f97cdb',1,'iconv.c']]],
  ['tds_5ficonv_5finit_161',['tds_iconv_init',['../a01502.html#a30bcae80553efae075b0886bfcda1e35',1,'iconv.c']]],
  ['tds_5fidle_162',['TDS_IDLE',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33ad1586abc1f75b7f3d640b994afe310e9',1,'tds.h']]],
  ['tds_5finit_5flogin_163',['tds_init_login',['../a00592.html#ga4f7b22f681e7160ac03dfe8d2ae8bd39',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c'],['../a00592.html#ga4f7b22f681e7160ac03dfe8d2ae8bd39',1,'tds_init_login(TDSLOGIN *login, TDSLOCALE *locale):&#160;mem.c']]],
  ['tds_5finput_5fstream_164',['tds_input_stream',['../a01169.html',1,'']]],
  ['tds_5fis_5fmssql_165',['TDS_IS_MSSQL',['../a00431.html#a07e9371c3e72b9e319f4c14e6fc2c20f',1,'tds.h']]],
  ['tds_5fis_5fsybase_166',['TDS_IS_SYBASE',['../a00431.html#a4840433488d0c66601ff4002a54b41d7',1,'tds.h']]],
  ['tds_5flocale_167',['tds_locale',['../a01233.html',1,'']]],
  ['tds_5flogin_168',['tds_login',['../a01225.html',1,'']]],
  ['tds_5flookup_5fdynamic_169',['tds_lookup_dynamic',['../a00595.html#ga4a45cadd06ae1b886459dcc1f8e482c6',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c'],['../a00595.html#ga4a45cadd06ae1b886459dcc1f8e482c6',1,'tds_lookup_dynamic(TDSCONNECTION *conn, const char *id):&#160;token.c']]],
  ['tds_5flookup_5fhost_170',['tds_lookup_host',['../a00589.html#ga3945f760ceb97e8854e18589d6f0d241',1,'tds_lookup_host(const char *servername):&#160;config.c'],['../a00589.html#ga3945f760ceb97e8854e18589d6f0d241',1,'tds_lookup_host(const char *servername):&#160;config.c']]],
  ['tds_5flookup_5fport_171',['tds_lookup_port',['../a00589.html#ga45281d1cb2ac649db65d80bb3ff06b66',1,'config.c']]],
  ['tds_5fmay_5falias_172',['TDS_MAY_ALIAS',['../a01017.html',1,'']]],
  ['tds_5fmessage_173',['tds_message',['../a01269.html',1,'']]],
  ['tds_5fmicrosoft_5fdbdaterec_174',['tds_microsoft_dbdaterec',['../a01445.html',1,'']]],
  ['tds_5fmicrosoft_5fdbdaterec2_175',['tds_microsoft_dbdaterec2',['../a01453.html',1,'']]],
  ['tds_5fms_5fver_176',['TDS_MS_VER',['../a00431.html#a1f5fb9d2184949ed566c8ce308a4e91e',1,'tds.h']]],
  ['tds_5fmultiple_177',['tds_multiple',['../a01293.html',1,'']]],
  ['tds_5fneeds_5funprepare_178',['tds_needs_unprepare',['../a00593.html#ga05ac7bab753d19b6ba1ffc7505d8fcd0',1,'tds_needs_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga05ac7bab753d19b6ba1ffc7505d8fcd0',1,'tds_needs_unprepare(TDSCONNECTION *conn, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fnext_5fplaceholder_179',['tds_next_placeholder',['../a00593.html#ga8f3b00c34af2484eccb169e60a37dc36',1,'tds_next_placeholder(const char *start):&#160;query.c'],['../a00593.html#ga8f3b00c34af2484eccb169e60a37dc36',1,'tds_next_placeholder(const char *start):&#160;query.c']]],
  ['tds_5fnext_5fplaceholder_5fucs2le_180',['tds_next_placeholder_ucs2le',['../a00593.html#gaaa97f8535a2babe642024a0744d271d5',1,'query.c']]],
  ['tds_5fntlm_5fauth_181',['tds_ntlm_auth',['../a00769.html',1,'']]],
  ['tds_5fntlm_5fget_5fauth_182',['tds_ntlm_get_auth',['../a00588.html#gac0f33825721aa985805d21540a254b87',1,'tds_ntlm_get_auth(TDSSOCKET *tds):&#160;challenge.c'],['../a00588.html#gac0f33825721aa985805d21540a254b87',1,'tds_ntlm_get_auth(TDSSOCKET *tds):&#160;challenge.c']]],
  ['tds_5fnumeric_5fbytes_5fper_5fprec_183',['tds_numeric_bytes_per_prec',['../a00431.html#a106d0db2e44beb1a52606579db907f7a',1,'numeric.c']]],
  ['tds_5fnumeric_5fto_5fstring_184',['tds_numeric_to_string',['../a00431.html#a622da936832b0337742da956be123719',1,'numeric.c']]],
  ['tds_5foption_5farg_185',['tds_option_arg',['../a01209.html',1,'']]],
  ['tds_5foutput_5fstream_186',['tds_output_stream',['../a01173.html',1,'']]],
  ['tds_5fpacket_187',['tds_packet',['../a01305.html',1,'']]],
  ['tds_5fparsed_5fparam_188',['TDS_PARSED_PARAM',['../a01109.html',1,'']]],
  ['tds_5fpbcb_189',['tds_pbcb',['../a00753.html',1,'']]],
  ['tds_5fpeek_190',['tds_peek',['../a00594.html#ga221e98a9c8be96ec6c8547891e1b53af',1,'tds_peek(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#ga221e98a9c8be96ec6c8547891e1b53af',1,'tds_peek(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fpending_191',['TDS_PENDING',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33a00f6d5ac5560f2f44661e599241849a8',1,'tds.h']]],
  ['tds_5fpoll_5fwakeup_192',['tds_poll_wakeup',['../a01309.html',1,'']]],
  ['tds_5fpool_193',['tds_pool',['../a00737.html',1,'']]],
  ['tds_5fpool_5fevent_194',['tds_pool_event',['../a00721.html',1,'']]],
  ['tds_5fpool_5fmember_195',['tds_pool_member',['../a00733.html',1,'']]],
  ['tds_5fpool_5fsocket_196',['tds_pool_socket',['../a00725.html',1,'']]],
  ['tds_5fpool_5fuser_197',['tds_pool_user',['../a00729.html',1,'']]],
  ['tds_5fpr_5fop_198',['tds_pr_op',['../a00595.html#ga62dc14d21453e88e24880ee0acaca73a',1,'token.c']]],
  ['tds_5fprdatatype_199',['tds_prdatatype',['../a00089.html#ac7a199aaeb82935f6d1dda2be551a089',1,'dblib.c']]],
  ['tds_5fprocess_5fauth_200',['tds_process_auth',['../a00595.html#ga4e1e52e09b0c27a9b9f53eb6b539afce',1,'token.c']]],
  ['tds_5fprocess_5fcancel_201',['tds_process_cancel',['../a00595.html#gaf233e79967f82f4e0dd4d11524917a34',1,'tds_process_cancel(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#gaf233e79967f82f4e0dd4d11524917a34',1,'tds_process_cancel(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5fcol_5ffmt_202',['tds_process_col_fmt',['../a00595.html#ga4e3dd9d3614f5f0433b78b761dd68741',1,'token.c']]],
  ['tds_5fprocess_5fcol_5fname_203',['tds_process_col_name',['../a00595.html#ga905d2fa5e1b602817bd16bb0fcf9eadb',1,'token.c']]],
  ['tds_5fprocess_5fcolinfo_204',['tds_process_colinfo',['../a00595.html#ga22c7f413d43fc0d511e122a3de389166',1,'token.c']]],
  ['tds_5fprocess_5fcompute_205',['tds_process_compute',['../a00595.html#ga6fcb37d5addebdc1af9f34ebc59fd7a8',1,'token.c']]],
  ['tds_5fprocess_5fcompute_5fnames_206',['tds_process_compute_names',['../a00595.html#gae5b3e01f3d665f9e377de091f46f1ab9',1,'token.c']]],
  ['tds_5fprocess_5fcompute_5fresult_207',['tds_process_compute_result',['../a00595.html#gae3368ea80d0d8b13791ceb13ee5f19c9',1,'token.c']]],
  ['tds_5fprocess_5fcursor_5ftokens_208',['tds_process_cursor_tokens',['../a00595.html#ga315d875d90c64d12d61fc9e33b4dee96',1,'token.c']]],
  ['tds_5fprocess_5fdefault_5ftokens_209',['tds_process_default_tokens',['../a00595.html#ga043499f57cf90d42d936f06ac2d8b777',1,'token.c']]],
  ['tds_5fprocess_5fdyn_5fresult_210',['tds_process_dyn_result',['../a00595.html#ga416cf119c1d4a0fca27dc5b50c261358',1,'token.c']]],
  ['tds_5fprocess_5fdynamic_211',['tds_process_dynamic',['../a00595.html#ga5cfc0340d8d717e67f60037e029b2142',1,'token.c']]],
  ['tds_5fprocess_5fend_212',['tds_process_end',['../a00595.html#ga6ee2e7af38af768611b8bf4b79c36f46',1,'token.c']]],
  ['tds_5fprocess_5fenv_5fchg_213',['tds_process_env_chg',['../a00595.html#ga3e1b4df4410a86a563a8c155e7799720',1,'token.c']]],
  ['tds_5fprocess_5finfo_214',['tds_process_info',['../a00595.html#ga65a2316369529731732f200c190d05d6',1,'token.c']]],
  ['tds_5fprocess_5flogin_5ftokens_215',['tds_process_login_tokens',['../a00595.html#ga93945b42d45ee28ae1296b35a1c1e9bb',1,'tds_process_login_tokens(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#ga93945b42d45ee28ae1296b35a1c1e9bb',1,'tds_process_login_tokens(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5fnbcrow_216',['tds_process_nbcrow',['../a00595.html#gaf7264c9eb3aa7a73358a4c65f02d3d3c',1,'token.c']]],
  ['tds_5fprocess_5fparam_5fresult_217',['tds_process_param_result',['../a00595.html#gacb3354443bcefe7a500a500a4904cc05',1,'token.c']]],
  ['tds_5fprocess_5fparam_5fresult_5ftokens_218',['tds_process_param_result_tokens',['../a00595.html#ga9fdef8228d29cab7fa9098f07fa73fba',1,'token.c']]],
  ['tds_5fprocess_5fparams_5fresult_5ftoken_219',['tds_process_params_result_token',['../a00595.html#ga7b18c0911a9dc69939577b39eb64725d',1,'token.c']]],
  ['tds_5fprocess_5fpending_5fcloses_220',['tds_process_pending_closes',['../a00595.html#ga69902dffb299d62a799888e0fa3ccd68',1,'token.c']]],
  ['tds_5fprocess_5frow_221',['tds_process_row',['../a00595.html#gaad814dd6e35aee8332035d06dc8b5d65',1,'token.c']]],
  ['tds_5fprocess_5fsimple_5fquery_222',['tds_process_simple_query',['../a00595.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c'],['../a00595.html#gaeeb1562044786ea17bea361ed83e6946',1,'tds_process_simple_query(TDSSOCKET *tds):&#160;token.c']]],
  ['tds_5fprocess_5ftabname_223',['tds_process_tabname',['../a00595.html#gaeec59bca9bd0c5388e245f0d19d9c81a',1,'token.c']]],
  ['tds_5fprocess_5ftokens_224',['tds_process_tokens',['../a00595.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c'],['../a00595.html#gabfc9de1d1fe718818caf63a4be4035a6',1,'tds_process_tokens(TDSSOCKET *tds, TDS_INT *result_type, int *done_flags, unsigned flag):&#160;token.c']]],
  ['tds_5fprtype_225',['tds_prtype',['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int type):&#160;token.c'],['../a00595.html#ga307f949194204f71f1a7e574424048b1',1,'tds_prtype(int token):&#160;token.c']]],
  ['tds_5fput_5fdata_226',['tds_put_data',['../a00593.html#ga9fcc0a3932dcad530511395ef8a767fb',1,'query.c']]],
  ['tds_5fput_5fdata_5finfo_227',['tds_put_data_info',['../a00593.html#gafd74652c4722ddce4d642cc4209449d4',1,'query.c']]],
  ['tds_5fput_5fn_5fas_5fucs2_228',['TDS_PUT_N_AS_UCS2',['../a00593.html#ga62c3dc9946acb3ffd1b7ae43424f5b47',1,'query.c']]],
  ['tds_5fput_5fparam_5fas_5fstring_229',['tds_put_param_as_string',['../a00593.html#ga0e2e7230c425e925402d7856ff5b4b18',1,'query.c']]],
  ['tds_5fput_5fstring_230',['tds_put_string',['../a00594.html#ga1fcaf8d488cc1390f106ce3ad0bf37b4',1,'tds_put_string(TDSSOCKET *tds, const char *s, int len):&#160;write.c'],['../a00594.html#ga1fcaf8d488cc1390f106ce3ad0bf37b4',1,'tds_put_string(TDSSOCKET *tds, const char *buf, int len):&#160;write.c']]],
  ['tds_5fput_5ftinyint_231',['tds_put_tinyint',['../a00431.html#adfc186758f4c1856c01746b5436aff74',1,'tds.h']]],
  ['tds_5fquery_5fflush_5fpacket_232',['tds_query_flush_packet',['../a00593.html#gada27f4cfce925240ad33b71b63ca692d',1,'query.c']]],
  ['tds_5fquote_233',['tds_quote',['../a00593.html#gaa4cb9266a930adc1f1e0f607f7d6edb5',1,'query.c']]],
  ['tds_5fquote_5fand_5fput_234',['tds_quote_and_put',['../a00593.html#ga26b26296d060dca75f6a43e9ac41e58d',1,'query.c']]],
  ['tds_5fquote_5fid_235',['tds_quote_id',['../a00593.html#ga33eb2806c6164ab56873a90f8fe82ad0',1,'tds_quote_id(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c'],['../a00593.html#ga33eb2806c6164ab56873a90f8fe82ad0',1,'tds_quote_id(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c']]],
  ['tds_5fquote_5fid_5frpc_236',['tds_quote_id_rpc',['../a00593.html#gae944bb16f055fcbeef3c9370447221f7',1,'tds_quote_id_rpc(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c'],['../a00593.html#gae944bb16f055fcbeef3c9370447221f7',1,'tds_quote_id_rpc(TDSSOCKET *tds, char *buffer, const char *id, ptrdiff_t idlen):&#160;query.c']]],
  ['tds_5fquote_5fstring_237',['tds_quote_string',['../a00593.html#ga4e738bcdca6650147ca60c8cf5721926',1,'query.c']]],
  ['tds_5fquoteout_5fstream_238',['tds_quoteout_stream',['../a00809.html',1,'']]],
  ['tds_5fraw_5fmutex_239',['tds_raw_mutex',['../a01345.html',1,'']]],
  ['tds_5fread_5fconf_5ffile_240',['tds_read_conf_file',['../a00589.html#ga4799b423b5d982dbc8f31b7738255eef',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c'],['../a00589.html#ga4799b423b5d982dbc8f31b7738255eef',1,'tds_read_conf_file(TDSLOGIN *login, const char *server):&#160;config.c']]],
  ['tds_5fread_5fconf_5fsection_241',['tds_read_conf_section',['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *param):&#160;config.c'],['../a00589.html#ga44fdbe16827097d947f900d96003de98',1,'tds_read_conf_section(FILE *in, const char *section, TDSCONFPARSE tds_conf_parse, void *parse_param):&#160;config.c']]],
  ['tds_5fread_5fconfig_5finfo_242',['tds_read_config_info',['../a00589.html#ga9ff2436ea56ddcdecf984acf46ce4b90',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c'],['../a00589.html#ga9ff2436ea56ddcdecf984acf46ce4b90',1,'tds_read_config_info(TDSSOCKET *tds, TDSLOGIN *login, TDSLOCALE *locale):&#160;config.c']]],
  ['tds_5fread_5finterfaces_243',['tds_read_interfaces',['../a00589.html#ga66de78d379cad2ee3d6c26948ad6445f',1,'config.c']]],
  ['tds_5fread_5fnamelist_244',['tds_read_namelist',['../a00595.html#gaeaaed2ea1d8c827da1a0f5b419524ae1',1,'token.c']]],
  ['tds_5fread_5fpacket_245',['tds_read_packet',['../a00594.html#ga410619783bdf2bb60b0f27a5578e0e07',1,'tds_read_packet(TDSSOCKET *tds):&#160;packet.c'],['../a00594.html#ga410619783bdf2bb60b0f27a5578e0e07',1,'tds_read_packet(TDSSOCKET *tds):&#160;packet.c']]],
  ['tds_5freading_246',['TDS_READING',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33a36ddbc8f326d6b297009a8fafd958529',1,'tds.h']]],
  ['tds_5frealloc_247',['tds_realloc',['../a00592.html#ga8645f5abc49db03d14b66f72b83a9a4c',1,'tds_realloc(void **pp, size_t new_size):&#160;mem.c'],['../a00592.html#ga8645f5abc49db03d14b66f72b83a9a4c',1,'tds_realloc(void **pp, size_t new_size):&#160;mem.c']]],
  ['tds_5frelease_5fdynamic_248',['tds_release_dynamic',['../a00592.html#gabf2fdb0def5388508602ee7dd2f49506',1,'tds_release_dynamic(TDSDYNAMIC **dyn):&#160;mem.c'],['../a00592.html#gabf2fdb0def5388508602ee7dd2f49506',1,'tds_release_dynamic(TDSDYNAMIC **pdyn):&#160;mem.c']]],
  ['tds_5fresult_5finfo_249',['tds_result_info',['../a01265.html',1,'']]],
  ['tds_5fsave_5fcontext_250',['tds_save_context',['../a00801.html',1,'']]],
  ['tds_5fsave_5fenv_251',['tds_save_env',['../a00797.html',1,'']]],
  ['tds_5fsave_5fmsg_252',['tds_save_msg',['../a00793.html',1,'']]],
  ['tds_5fselect_253',['tds_select',['../a00594.html#gad7aae89e32444ab30852fee056231403',1,'tds_select(TDSSOCKET *tds, unsigned tds_sel, int timeout_seconds):&#160;net.c'],['../a00594.html#gad7aae89e32444ab30852fee056231403',1,'tds_select(TDSSOCKET *tds, unsigned tds_sel, int timeout_seconds):&#160;net.c']]],
  ['tds_5fsend_5fcancel_254',['tds_send_cancel',['../a00593.html#ga11338742dc30fd0c2711f58eb830316f',1,'tds_send_cancel(TDSSOCKET *tds):&#160;query.c'],['../a00593.html#ga11338742dc30fd0c2711f58eb830316f',1,'tds_send_cancel(TDSSOCKET *tds):&#160;query.c']]],
  ['tds_5fsend_5femulated_5fexecute_255',['tds_send_emulated_execute',['../a00593.html#ga02c6ce3ff96369603a6ee4efee64caae',1,'query.c']]],
  ['tds_5fsending_256',['TDS_SENDING',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33a2bad5be30bd85edc9495dae3d199d2c1',1,'tds.h']]],
  ['tds_5fset_5fcolumn_5ftype_257',['tds_set_column_type',['../a00263.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00431.html#a31604382d8b77257aad203f409155a29',1,'tds_set_column_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
  ['tds_5fset_5fcur_5fcursor_258',['tds_set_cur_cursor',['../a00593.html#ga34fb1084682cc31fe02a4a7946955a5a',1,'query.c']]],
  ['tds_5fset_5fcur_5fdyn_259',['tds_set_cur_dyn',['../a00593.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#gae8b7db85af16701fc0604eb117cbd4e4',1,'tds_set_cur_dyn(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fset_5ficonv_5fname_260',['tds_set_iconv_name',['../a01502.html#a585ebac61354ce540d28f6da2d771b5b',1,'iconv.c']]],
  ['tds_5fset_5finterfaces_5ffile_5floc_261',['tds_set_interfaces_file_loc',['../a00589.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interf):&#160;config.c'],['../a00589.html#ga57cea6e376d7c2d28b811a5b0053210c',1,'tds_set_interfaces_file_loc(const char *interfloc):&#160;config.c']]],
  ['tds_5fset_5fparam_5ftype_262',['tds_set_param_type',['../a00263.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c'],['../a00431.html#a86768d86059c5addf9a3f89edb1ef44e',1,'tds_set_param_type(TDSCONNECTION *conn, TDSCOLUMN *curcol, TDS_SERVER_TYPE type):&#160;data.c']]],
  ['tds_5fset_5fserver_263',['tds_set_server',['../a00431.html#a3ab8874994a0776acdaff797afdb710a',1,'login.c']]],
  ['tds_5fset_5fstate_264',['tds_set_state',['../a00431.html#a16db200d2281f76fe46fc1cbe37ca9df',1,'util.c']]],
  ['tds_5fsetup_5fsocket_265',['tds_setup_socket',['../a00594.html#gab604dd1d75afa8f852d1a6ee0b681974',1,'net.c']]],
  ['tds_5fskip_5fcomment_266',['tds_skip_comment',['../a00593.html#gacf0a4f2a1c2166588f4d232eda737cf5',1,'tds_skip_comment(const char *s):&#160;query.c'],['../a00593.html#gacf0a4f2a1c2166588f4d232eda737cf5',1,'tds_skip_comment(const char *s):&#160;query.c']]],
  ['tds_5fskip_5fcomment_5fucs2le_267',['tds_skip_comment_ucs2le',['../a00593.html#gac3124fe439d9c96236fc33af7793ffcf',1,'query.c']]],
  ['tds_5fskip_5fquoted_268',['tds_skip_quoted',['../a00593.html#ga0856776b63a475de7cd3fb62b1af2411',1,'tds_skip_quoted(const char *s):&#160;query.c'],['../a00593.html#ga0856776b63a475de7cd3fb62b1af2411',1,'tds_skip_quoted(const char *s):&#160;query.c']]],
  ['tds_5fskip_5fquoted_5fucs2le_269',['tds_skip_quoted_ucs2le',['../a00593.html#gab42efeaf6c795435a03de1835b3de1c6',1,'query.c']]],
  ['tds_5fsocket_270',['tds_socket',['../a01317.html',1,'']]],
  ['tds_5fsocket_5fread_271',['tds_socket_read',['../a00594.html#gad008344450bce3d0911fa4121dba9163',1,'net.c']]],
  ['tds_5fsocket_5fset_5fnonblocking_272',['tds_socket_set_nonblocking',['../a00594.html#ga2a7429ff031f77023d1bf31339a266db',1,'tds_socket_set_nonblocking(TDS_SYS_SOCKET sock):&#160;net.c'],['../a00594.html#ga2a7429ff031f77023d1bf31339a266db',1,'tds_socket_set_nonblocking(TDS_SYS_SOCKET sock):&#160;net.c']]],
  ['tds_5fsocket_5fset_5fnosigpipe_273',['tds_socket_set_nosigpipe',['../a00594.html#ga31200649c72e81c9d5d07352573ce9f1',1,'tds_socket_set_nosigpipe(TDS_SYS_SOCKET sock TDS_UNUSED, int on TDS_UNUSED):&#160;net.c'],['../a00594.html#ga31200649c72e81c9d5d07352573ce9f1',1,'tds_socket_set_nosigpipe(TDS_SYS_SOCKET sock, int on):&#160;net.c']]],
  ['tds_5fsocket_5fwrite_274',['tds_socket_write',['../a00594.html#ga9b377b1cd287fd20db54bbca02a954b9',1,'net.c']]],
  ['tds_5fstart_5fquery_275',['tds_start_query',['../a00593.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c'],['../a00593.html#ga0da385231bfa3dc49377e1fb2bea2c07',1,'tds_start_query(TDSSOCKET *tds, unsigned char packet_type):&#160;query.c']]],
  ['tds_5fstart_5fquery_5fhead_276',['tds_start_query_head',['../a00593.html#ga9ad2e6defce530a8778791cce0166ccd',1,'query.c']]],
  ['tds_5fstate_277',['TDS_STATE',['../a00431.html#ac0d502ab90609c39fe7713fe0dfbefad',1,'tds.h']]],
  ['tds_5fstates_278',['tds_states',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33',1,'tds.h']]],
  ['tds_5fstaticin_5fstream_279',['tds_staticin_stream',['../a01185.html',1,'']]],
  ['tds_5fstaticin_5fstream_5finit_280',['tds_staticin_stream_init',['../a01490.html#aa9e1e45f0305622dd6aed9f8fe158581',1,'stream.c']]],
  ['tds_5fstaticin_5fstream_5fread_281',['tds_staticin_stream_read',['../a01490.html#a76b02f1fa5b79dc7e1ef2651a9afe3f7',1,'stream.c']]],
  ['tds_5fstaticout_5fstream_282',['tds_staticout_stream',['../a01189.html',1,'']]],
  ['tds_5fstaticout_5fstream_5finit_283',['tds_staticout_stream_init',['../a01490.html#a9fe0d3799d2e3bde49b614c9d0c3785d',1,'stream.c']]],
  ['tds_5fstaticout_5fstream_5fwrite_284',['tds_staticout_stream_write',['../a01490.html#a1d92ebe06f18378ac17ccfd20db05126',1,'stream.c']]],
  ['tds_5fstr_5fempty_285',['tds_str_empty',['../a00596.html#ga676fd3c5c489584d09c89d66c7a0af2d',1,'tds_str_empty:&#160;tdsstring.c'],['../a00596.html#ga676fd3c5c489584d09c89d66c7a0af2d',1,'tds_str_empty:&#160;tdsstring.c']]],
  ['tds_5fstrftime_286',['tds_strftime',['../a00590.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *dr, int prec):&#160;convert.c'],['../a00590.html#ga8c9652e8b1f3e56a3289fd71b12cee1d',1,'tds_strftime(char *buf, size_t maxsize, const char *format, const TDSDATEREC *timeptr, int prec):&#160;convert.c']]],
  ['tds_5fsubmit_5fbegin_5ftran_287',['tds_submit_begin_tran',['../a00593.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c'],['../a00593.html#ga7bf3670d3d6dabed469b9eb117298079',1,'tds_submit_begin_tran(TDSSOCKET *tds):&#160;query.c']]],
  ['tds_5fsubmit_5fcommit_288',['tds_submit_commit',['../a00593.html#ga7d68588fdd0beeae52197a6d6cef8754',1,'tds_submit_commit(TDSSOCKET *tds, bool cont):&#160;query.c'],['../a00593.html#ga7d68588fdd0beeae52197a6d6cef8754',1,'tds_submit_commit(TDSSOCKET *tds, bool cont):&#160;query.c']]],
  ['tds_5fsubmit_5fexecdirect_289',['tds_submit_execdirect',['../a00593.html#gae603aed795a4c5bb26ab159a11256996',1,'tds_submit_execdirect(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00593.html#gae603aed795a4c5bb26ab159a11256996',1,'tds_submit_execdirect(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5fexecute_290',['tds_submit_execute',['../a00593.html#ga3e7b4793c6f799fbc6c174f673bb5b32',1,'tds_submit_execute(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#ga3e7b4793c6f799fbc6c174f673bb5b32',1,'tds_submit_execute(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fsubmit_5foptioncmd_291',['tds_submit_optioncmd',['../a00593.html#gaf0da49585d39e99780a004ee2ca23479',1,'tds_submit_optioncmd(TDSSOCKET *tds, TDS_OPTION_CMD command, TDS_OPTION option, TDS_OPTION_ARG *param, TDS_INT param_size):&#160;query.c'],['../a00593.html#gaf0da49585d39e99780a004ee2ca23479',1,'tds_submit_optioncmd(TDSSOCKET *tds, TDS_OPTION_CMD command, TDS_OPTION option, TDS_OPTION_ARG *param, TDS_INT param_size):&#160;query.c']]],
  ['tds_5fsubmit_5fprepare_292',['tds_submit_prepare',['../a00593.html#ga74eb08c3a1c85be8ac9db428842c8b9d',1,'tds_submit_prepare(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c'],['../a00593.html#ga74eb08c3a1c85be8ac9db428842c8b9d',1,'tds_submit_prepare(TDSSOCKET *tds, const char *query, const char *id, TDSDYNAMIC **dyn_out, TDSPARAMINFO *params):&#160;query.c']]],
  ['tds_5fsubmit_5fquery_293',['tds_submit_query',['../a00593.html#ga5a29ae7f99d089dc3cea85ec6ee5f3ab',1,'tds_submit_query(TDSSOCKET *tds, const char *query):&#160;query.c'],['../a00593.html#ga5a29ae7f99d089dc3cea85ec6ee5f3ab',1,'tds_submit_query(TDSSOCKET *tds, const char *query):&#160;query.c']]],
  ['tds_5fsubmit_5fquery_5fparams_294',['tds_submit_query_params',['../a00593.html#ga95e0fccedc459a4404f496eec74a369a',1,'tds_submit_query_params(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00593.html#ga95e0fccedc459a4404f496eec74a369a',1,'tds_submit_query_params(TDSSOCKET *tds, const char *query, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5fqueryf_295',['tds_submit_queryf',['../a00593.html#gad695defcbf663b0023851a198206a772',1,'tds_submit_queryf(TDSSOCKET *tds, const char *queryf,...):&#160;query.c'],['../a00593.html#gad695defcbf663b0023851a198206a772',1,'tds_submit_queryf(TDSSOCKET *tds, const char *queryf,...):&#160;query.c']]],
  ['tds_5fsubmit_5frollback_296',['tds_submit_rollback',['../a00593.html#ga7f20f58e43ba5eb916c97c7396395563',1,'tds_submit_rollback(TDSSOCKET *tds, bool cont):&#160;query.c'],['../a00593.html#ga7f20f58e43ba5eb916c97c7396395563',1,'tds_submit_rollback(TDSSOCKET *tds, bool cont):&#160;query.c']]],
  ['tds_5fsubmit_5frpc_297',['tds_submit_rpc',['../a00593.html#ga5f071b94ad7889690762dc85646c74ab',1,'tds_submit_rpc(TDSSOCKET *tds, const char *rpc_name, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c'],['../a00593.html#ga5f071b94ad7889690762dc85646c74ab',1,'tds_submit_rpc(TDSSOCKET *tds, const char *rpc_name, TDSPARAMINFO *params, TDSHEADERS *head):&#160;query.c']]],
  ['tds_5fsubmit_5funprepare_298',['tds_submit_unprepare',['../a00593.html#gaf573d8d4d2660c8c27770573fca05ff5',1,'tds_submit_unprepare(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c'],['../a00593.html#gaf573d8d4d2660c8c27770573fca05ff5',1,'tds_submit_unprepare(TDSSOCKET *tds, TDSDYNAMIC *dyn):&#160;query.c']]],
  ['tds_5fswap_5fnumeric_299',['tds_swap_numeric',['../a00263.html#aa818c1cbf4d16e609b7e4895cc7ed74f',1,'data.c']]],
  ['tds_5fsyb_5fver_300',['TDS_SYB_VER',['../a00431.html#aca53a637849948c4b7a07f69e40c685c',1,'tds.h']]],
  ['tds_5fsybase_5fdbdaterec_301',['tds_sybase_dbdaterec',['../a01449.html',1,'']]],
  ['tds_5fsybase_5fdbdaterec2_302',['tds_sybase_dbdaterec2',['../a01457.html',1,'']]],
  ['tds_5fsys_5ficonv_5fopen_303',['tds_sys_iconv_open',['../a00591.html#ga900b0bce08c6bfc2e7c988f4b5970516',1,'tds_sys_iconv_open(const char *tocode, const char *fromcode):&#160;iconv.c'],['../a00591.html#ga900b0bce08c6bfc2e7c988f4b5970516',1,'tds_sys_iconv_open(const char *tocode, const char *fromcode):&#160;iconv.c']]],
  ['tds_5fthread_304',['tds_thread',['../a01353.html',1,'']]],
  ['tds_5ftime_305',['tds_time',['../a00781.html',1,'']]],
  ['tds_5ftoken_5fname_306',['tds_token_name',['../a00595.html#ga7f24a7af985cd320788122e98072b7af',1,'token.c']]],
  ['tds_5ftvp_307',['tds_tvp',['../a01325.html',1,'']]],
  ['tds_5ftvp_5frow_308',['tds_tvp_row',['../a01321.html',1,'']]],
  ['tds_5funget_5fbyte_309',['tds_unget_byte',['../a00594.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c'],['../a00594.html#gad70d59fb317d098b0c9fd29dd77131a8',1,'tds_unget_byte(TDSSOCKET *tds):&#160;read.c']]],
  ['tds_5fupd_5fcol_310',['tds_upd_col',['../a01273.html',1,'']]],
  ['tds_5fvariant_311',['tds_variant',['../a01241.html',1,'']]],
  ['tds_5fvarmax_5fstream_312',['tds_varmax_stream',['../a00785.html',1,'']]],
  ['tds_5fversion_313',['tds_version',['../a01225.html#a8f9f756b25fd18916a6080f9c22f835d',1,'tds_login']]],
  ['tds_5fwillconvert_314',['tds_willconvert',['../a00590.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c'],['../a00590.html#ga80487b313213f60d8be71a50a002bb2c',1,'tds_willconvert(int srctype, int desttype):&#160;convert.c']]],
  ['tds_5fwrite_5fdump_315',['tds_write_dump',['../a00431.html#a02866a1bf7da5ab66a994217fcceb1b7',1,'log.c']]],
  ['tds_5fwritetext_5fcontinue_316',['tds_writetext_continue',['../a00254.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c'],['../a00431.html#ab68dead99a2ebec55895a10cd3db5202',1,'tds_writetext_continue(TDSSOCKET *tds, const TDS_UCHAR *text, TDS_UINT size):&#160;bulk.c']]],
  ['tds_5fwritetext_5fend_317',['tds_writetext_end',['../a00254.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c'],['../a00431.html#ac1e460551f1188620ea478238864ac4b',1,'tds_writetext_end(TDSSOCKET *tds):&#160;bulk.c']]],
  ['tds_5fwritetext_5fstart_318',['tds_writetext_start',['../a00254.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c'],['../a00431.html#a7711612cc544a7da2c7aa212b870acb2',1,'tds_writetext_start(TDSSOCKET *tds, const char *objname, const char *textptr, const char *timestamp, int with_log, TDS_UINT size):&#160;bulk.c']]],
  ['tds_5fwriting_319',['TDS_WRITING',['../a00431.html#a87cdae58f91ebe9229206bf0628f8e33a4a4fcc1840bee1e09521f08a0184d025',1,'tds.h']]],
  ['tdsblob_320',['TDSBLOB',['../a00431.html#a47b154752431b2379988dbfdff394577',1,'tds.h']]],
  ['tdscursor_321',['TDSCURSOR',['../a00431.html#afe061eb245f3006d93940a20415692a7',1,'tds.h']]],
  ['tdsdaterec_322',['tdsdaterec',['../a01205.html',1,'tdsdaterec'],['../a00431.html#a3b40b4faf314267146c2005e56eebe7b',1,'TDSDATEREC:&#160;tds.h']]],
  ['tdsdatetime_323',['tdsdatetime',['../a01137.html',1,'']]],
  ['tdsdatetime4_324',['tdsdatetime4',['../a01141.html',1,'']]],
  ['tdsdbopen_325',['tdsdbopen',['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c'],['../a00584.html#gae6da75d7b9e7b567890fc83c9459d824',1,'tdsdbopen(LOGINREC *login, const char *server, int msdblib):&#160;dblib.c']]],
  ['tdsdump_5fclose_326',['tdsdump_close',['../a00431.html#a2f00fc0907d3bb04ce0eeb9738e08d0c',1,'log.c']]],
  ['tdsdump_5fcol_327',['tdsdump_col',['../a00431.html#aaee3fe5c514ce5570c9548de9b16e0d9',1,'log.c']]],
  ['tdsdump_5fdump_5fbuf_5fimpl_328',['tdsdump_dump_buf_impl',['../a00431.html#a60cebdbb8c6750d36c68fcb1949ce83a',1,'log.c']]],
  ['tdsdump_5flog_5fimpl_329',['tdsdump_log_impl',['../a00431.html#aa45e90c7bdceb30a826c123ad66da9e4',1,'log.c']]],
  ['tdsdump_5foff_330',['tdsdump_off',['../a00431.html#ae3e5e04822595c54f86db66d9e40b93a',1,'log.c']]],
  ['tdsdump_5foff_5fitem_331',['tdsdump_off_item',['../a01329.html',1,'']]],
  ['tdsdump_5fon_332',['tdsdump_on',['../a00431.html#ae5f50062ebebe46b951e5308cb2f5d7e',1,'log.c']]],
  ['tdsdump_5fopen_333',['tdsdump_open',['../a00431.html#a24471508ddfde7cc0f8577801e70c42f',1,'log.c']]],
  ['tdsdynamic_334',['TDSDYNAMIC',['../a00431.html#a856d78b7438fef3d6e6c0a8e4566d978',1,'tds.h']]],
  ['tdsenv_335',['TDSENV',['../a00431.html#a42c559939ed16a39c0318a6f543c576e',1,'tds.h']]],
  ['tdserror_336',['tdserror',['../a00431.html#abf18b98efef6ce2dc0b97d658a3a1918',1,'util.c']]],
  ['tdsfilestream_337',['TDSFILESTREAM',['../a00254.html#ac2b7f7b7bb486f90e1053bfb829ca2ba',1,'bulk.c']]],
  ['tdsiconvdir_338',['tdsiconvdir',['../a01049.html',1,'']]],
  ['tdsiconvinfo_339',['tdsiconvinfo',['../a01053.html',1,'']]],
  ['tdsmoney_340',['tdsmoney',['../a01129.html',1,'']]],
  ['tdsmoney4_341',['tdsmoney4',['../a01133.html',1,'']]],
  ['tdsnumeric_342',['tdsnumeric',['../a01121.html',1,'']]],
  ['tdsoldmoney_343',['tdsoldmoney',['../a01125.html',1,'']]],
  ['tdspbcb_344',['TDSPBCB',['../a00254.html#af31a5af3c7480dc3a16576dfc84f3b06',1,'bulk.c']]],
  ['tdsunique_345',['tdsunique',['../a01145.html',1,'']]],
  ['tdsvariant_346',['TDSVARIANT',['../a00431.html#a25488abe3449d4cdaaa97587d34f9174',1,'tds.h']]],
  ['tdsvername_5ft_347',['tdsvername_t',['../a00777.html',1,'']]],
  ['term_5flen_348',['term_len',['../a00757.html#aae893302d33ee1e9d83c3d85d7390dca',1,'tds_file_stream']]],
  ['terminator_349',['terminator',['../a00757.html#a463c28a7d862c0a6d7bf3170dd614dc0',1,'tds_file_stream']]],
  ['the_20db_20lib_20api_350',['The db-lib API',['../a00577.html',1,'']]],
  ['time_351',['time',['../a01201.html#afd6a58ec251f2c08a040917ba5a8cd3f',1,'TDS_DATETIMEALL::time'],['../a01425.html#a6bb5dcd5b47813b71934546e0c60e035',1,'DBDATETIMEALL::time']]],
  ['timezone_352',['timezone',['../a01205.html#a624e21e65d0ae89797b3a7eadc48829f',1,'tdsdaterec']]],
  ['tm_5fhour_353',['tm_hour',['../a00781.html#a6ece03e77f69035da83d5739e16ef905',1,'tds_time']]],
  ['tm_5fmday_354',['tm_mday',['../a00781.html#a8dfc26d484c247040f521f20288651f1',1,'tds_time']]],
  ['tm_5fmin_355',['tm_min',['../a00781.html#ab50f30e05dc6b493d347918ab7ded1e9',1,'tds_time']]],
  ['tm_5fmon_356',['tm_mon',['../a00781.html#adce28126e9bbd4ef005e3bf181d59745',1,'tds_time']]],
  ['tm_5fns_357',['tm_ns',['../a00781.html#a386f1cfcabbe3ed86afe72bed75778cf',1,'tds_time']]],
  ['tm_5fsec_358',['tm_sec',['../a00781.html#adeb5e3f535662c0341d28f8d669cb59b',1,'tds_time']]],
  ['tm_5fyear_359',['tm_year',['../a00781.html#a3e27d50ebb5196356a6a8a9b495c8758',1,'tds_time']]],
  ['tmp_5fbuf_360',['tmp_buf',['../a00645.html',1,'']]],
  ['tmp_5fcol_5fstruct_361',['tmp_col_struct',['../a00741.html',1,'']]],
  ['to_20add_20a_20new_20type_362',['How to add a new type',['../a01458.html',1,'']]],
  ['todo_20list_363',['Todo List',['../a00575.html',1,'']]],
  ['token_2ec_364',['token.c',['../a00251.html',1,'']]],
  ['type_365',['type',['../a01458.html',1,'How to add a new type'],['../a01281.html#a889aafdde1d57c9be0585326022831f0',1,'tds_cursor::type']]]
];
